# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/entailment/v1/entailment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/entailment/v1/entailment.proto',
  package='arg_services.entailment.v1',
  syntax='proto3',
  serialized_options=b'\n-de.uni_trier.recap.arg_services.entailment.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+arg_services/entailment/v1/entailment.proto\x12\x1a\x61rg_services.entailment.v1\"E\n\x11\x45ntailmentRequest\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0f\n\x07premise\x18\x02 \x01(\t\x12\r\n\x05\x63laim\x18\x03 \x01(\t\"T\n\x12\x45ntailmentsRequest\x12>\n\x07queries\x18\x01 \x03(\x0b\x32-.arg_services.entailment.v1.EntailmentRequest\"\x85\x01\n\x12\x45ntailmentResponse\x12:\n\nprediction\x18\x01 \x01(\x0e\x32&.arg_services.entailment.v1.Prediction\x12\x33\n\x07\x64\x65tails\x18\x02 \x03(\x0b\x32\".arg_services.entailment.v1.Detail\"V\n\x13\x45ntailmentsResponse\x12?\n\x07results\x18\x01 \x03(\x0b\x32..arg_services.entailment.v1.EntailmentResponse\"Y\n\x06\x44\x65tail\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12:\n\nprediction\x18\x02 \x01(\x0e\x32&.arg_services.entailment.v1.Prediction*y\n\nPrediction\x12\x1a\n\x16PREDICTION_UNSPECIFIED\x10\x00\x12\x19\n\x15PREDICTION_ENTAILMENT\x10\x01\x12\x1c\n\x18PREDICTION_CONTRADICTION\x10\x02\x12\x16\n\x12PREDICTION_NEUTRAL\x10\x03\x32\xf0\x01\n\x11\x45ntailmentService\x12k\n\nEntailment\x12-.arg_services.entailment.v1.EntailmentRequest\x1a..arg_services.entailment.v1.EntailmentResponse\x12n\n\x0b\x45ntailments\x12..arg_services.entailment.v1.EntailmentsRequest\x1a/.arg_services.entailment.v1.EntailmentsResponseB/\n-de.uni_trier.recap.arg_services.entailment.v1b\x06proto3'
)

_PREDICTION = _descriptor.EnumDescriptor(
  name='Prediction',
  full_name='arg_services.entailment.v1.Prediction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_ENTAILMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_CONTRADICTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_NEUTRAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=547,
  serialized_end=668,
)
_sym_db.RegisterEnumDescriptor(_PREDICTION)

Prediction = enum_type_wrapper.EnumTypeWrapper(_PREDICTION)
PREDICTION_UNSPECIFIED = 0
PREDICTION_ENTAILMENT = 1
PREDICTION_CONTRADICTION = 2
PREDICTION_NEUTRAL = 3



_ENTAILMENTREQUEST = _descriptor.Descriptor(
  name='EntailmentRequest',
  full_name='arg_services.entailment.v1.EntailmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='arg_services.entailment.v1.EntailmentRequest.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premise', full_name='arg_services.entailment.v1.EntailmentRequest.premise', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim', full_name='arg_services.entailment.v1.EntailmentRequest.claim', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=144,
)


_ENTAILMENTSREQUEST = _descriptor.Descriptor(
  name='EntailmentsRequest',
  full_name='arg_services.entailment.v1.EntailmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queries', full_name='arg_services.entailment.v1.EntailmentsRequest.queries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=230,
)


_ENTAILMENTRESPONSE = _descriptor.Descriptor(
  name='EntailmentResponse',
  full_name='arg_services.entailment.v1.EntailmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction', full_name='arg_services.entailment.v1.EntailmentResponse.prediction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='arg_services.entailment.v1.EntailmentResponse.details', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=366,
)


_ENTAILMENTSRESPONSE = _descriptor.Descriptor(
  name='EntailmentsResponse',
  full_name='arg_services.entailment.v1.EntailmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='arg_services.entailment.v1.EntailmentsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=454,
)


_DETAIL = _descriptor.Descriptor(
  name='Detail',
  full_name='arg_services.entailment.v1.Detail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='arg_services.entailment.v1.Detail.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction', full_name='arg_services.entailment.v1.Detail.prediction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=545,
)

_ENTAILMENTSREQUEST.fields_by_name['queries'].message_type = _ENTAILMENTREQUEST
_ENTAILMENTRESPONSE.fields_by_name['prediction'].enum_type = _PREDICTION
_ENTAILMENTRESPONSE.fields_by_name['details'].message_type = _DETAIL
_ENTAILMENTSRESPONSE.fields_by_name['results'].message_type = _ENTAILMENTRESPONSE
_DETAIL.fields_by_name['prediction'].enum_type = _PREDICTION
DESCRIPTOR.message_types_by_name['EntailmentRequest'] = _ENTAILMENTREQUEST
DESCRIPTOR.message_types_by_name['EntailmentsRequest'] = _ENTAILMENTSREQUEST
DESCRIPTOR.message_types_by_name['EntailmentResponse'] = _ENTAILMENTRESPONSE
DESCRIPTOR.message_types_by_name['EntailmentsResponse'] = _ENTAILMENTSRESPONSE
DESCRIPTOR.message_types_by_name['Detail'] = _DETAIL
DESCRIPTOR.enum_types_by_name['Prediction'] = _PREDICTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EntailmentRequest = _reflection.GeneratedProtocolMessageType('EntailmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTAILMENTREQUEST,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.EntailmentRequest)
  })
_sym_db.RegisterMessage(EntailmentRequest)

EntailmentsRequest = _reflection.GeneratedProtocolMessageType('EntailmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTAILMENTSREQUEST,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.EntailmentsRequest)
  })
_sym_db.RegisterMessage(EntailmentsRequest)

EntailmentResponse = _reflection.GeneratedProtocolMessageType('EntailmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENTAILMENTRESPONSE,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.EntailmentResponse)
  })
_sym_db.RegisterMessage(EntailmentResponse)

EntailmentsResponse = _reflection.GeneratedProtocolMessageType('EntailmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENTAILMENTSRESPONSE,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.EntailmentsResponse)
  })
_sym_db.RegisterMessage(EntailmentsResponse)

Detail = _reflection.GeneratedProtocolMessageType('Detail', (_message.Message,), {
  'DESCRIPTOR' : _DETAIL,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.Detail)
  })
_sym_db.RegisterMessage(Detail)


DESCRIPTOR._options = None

_ENTAILMENTSERVICE = _descriptor.ServiceDescriptor(
  name='EntailmentService',
  full_name='arg_services.entailment.v1.EntailmentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=671,
  serialized_end=911,
  methods=[
  _descriptor.MethodDescriptor(
    name='Entailment',
    full_name='arg_services.entailment.v1.EntailmentService.Entailment',
    index=0,
    containing_service=None,
    input_type=_ENTAILMENTREQUEST,
    output_type=_ENTAILMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Entailments',
    full_name='arg_services.entailment.v1.EntailmentService.Entailments',
    index=1,
    containing_service=None,
    input_type=_ENTAILMENTSREQUEST,
    output_type=_ENTAILMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENTAILMENTSERVICE)

DESCRIPTOR.services_by_name['EntailmentService'] = _ENTAILMENTSERVICE

# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.nlp.v1.nlp_pb2
import grpc

class NlpServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    DocBin: grpc.UnaryUnaryMultiCallable[
        arg_services.nlp.v1.nlp_pb2.DocBinRequest,
        arg_services.nlp.v1.nlp_pb2.DocBinResponse] = ...

    Vectors: grpc.UnaryUnaryMultiCallable[
        arg_services.nlp.v1.nlp_pb2.VectorsRequest,
        arg_services.nlp.v1.nlp_pb2.VectorsResponse] = ...

    Similarities: grpc.UnaryUnaryMultiCallable[
        arg_services.nlp.v1.nlp_pb2.SimilaritiesRequest,
        arg_services.nlp.v1.nlp_pb2.SimilaritiesResponse] = ...
    """rpc ResetCache (ResetCacheRequest) returns (ResetCacheResponse);"""


class NlpServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def DocBin(self,
        request: arg_services.nlp.v1.nlp_pb2.DocBinRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.nlp.v1.nlp_pb2.DocBinResponse: ...

    @abc.abstractmethod
    def Vectors(self,
        request: arg_services.nlp.v1.nlp_pb2.VectorsRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.nlp.v1.nlp_pb2.VectorsResponse: ...

    @abc.abstractmethod
    def Similarities(self,
        request: arg_services.nlp.v1.nlp_pb2.SimilaritiesRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.nlp.v1.nlp_pb2.SimilaritiesResponse:
        """rpc ResetCache (ResetCacheRequest) returns (ResetCacheResponse);"""
        pass


def add_NlpServiceServicer_to_server(servicer: NlpServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.adu.v1.adu_pb2
import grpc

class AduServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Segmentation: grpc.UnaryUnaryMultiCallable[
        arg_services.adu.v1.adu_pb2.SegmentationRequest,
        arg_services.adu.v1.adu_pb2.SegmentationResponse] = ...

    Classification: grpc.UnaryUnaryMultiCallable[
        arg_services.adu.v1.adu_pb2.ClassificationRequest,
        arg_services.adu.v1.adu_pb2.ClassificationResponse] = ...
    """rpc TwoWay (TwoWayRequest) returns (TwoWayResponse);
    rpc ThreeWay (ThreeWayRequest) returns (ThreeWayResponse);
    rpc Sequential (SequentialRequest) returns (SequentialResponse);
    """


class AduServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Segmentation(self,
        request: arg_services.adu.v1.adu_pb2.SegmentationRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.adu.v1.adu_pb2.SegmentationResponse: ...

    @abc.abstractmethod
    def Classification(self,
        request: arg_services.adu.v1.adu_pb2.ClassificationRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.adu.v1.adu_pb2.ClassificationResponse:
        """rpc TwoWay (TwoWayRequest) returns (TwoWayResponse);
        rpc ThreeWay (ThreeWayRequest) returns (ThreeWayResponse);
        rpc Sequential (SequentialRequest) returns (SequentialResponse);
        """
        pass


def add_AduServiceServicer_to_server(servicer: AduServiceServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from arg_services.adu.v1 import adu_pb2 as arg__services_dot_adu_dot_v1_dot_adu__pb2


class AduServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Segmentation = channel.unary_unary(
                '/arg_services.adu.v1.AduService/Segmentation',
                request_serializer=arg__services_dot_adu_dot_v1_dot_adu__pb2.SegmentationRequest.SerializeToString,
                response_deserializer=arg__services_dot_adu_dot_v1_dot_adu__pb2.SegmentationResponse.FromString,
                )
        self.Classification = channel.unary_unary(
                '/arg_services.adu.v1.AduService/Classification',
                request_serializer=arg__services_dot_adu_dot_v1_dot_adu__pb2.ClassificationRequest.SerializeToString,
                response_deserializer=arg__services_dot_adu_dot_v1_dot_adu__pb2.ClassificationResponse.FromString,
                )


class AduServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Segmentation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Classification(self, request, context):
        """rpc TwoWay (TwoWayRequest) returns (TwoWayResponse);
        rpc ThreeWay (ThreeWayRequest) returns (ThreeWayResponse);
        rpc Sequential (SequentialRequest) returns (SequentialResponse);
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AduServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Segmentation': grpc.unary_unary_rpc_method_handler(
                    servicer.Segmentation,
                    request_deserializer=arg__services_dot_adu_dot_v1_dot_adu__pb2.SegmentationRequest.FromString,
                    response_serializer=arg__services_dot_adu_dot_v1_dot_adu__pb2.SegmentationResponse.SerializeToString,
            ),
            'Classification': grpc.unary_unary_rpc_method_handler(
                    servicer.Classification,
                    request_deserializer=arg__services_dot_adu_dot_v1_dot_adu__pb2.ClassificationRequest.FromString,
                    response_serializer=arg__services_dot_adu_dot_v1_dot_adu__pb2.ClassificationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'arg_services.adu.v1.AduService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AduService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Segmentation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.adu.v1.AduService/Segmentation',
            arg__services_dot_adu_dot_v1_dot_adu__pb2.SegmentationRequest.SerializeToString,
            arg__services_dot_adu_dot_v1_dot_adu__pb2.SegmentationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Classification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.adu.v1.AduService/Classification',
            arg__services_dot_adu_dot_v1_dot_adu__pb2.ClassificationRequest.SerializeToString,
            arg__services_dot_adu_dot_v1_dot_adu__pb2.ClassificationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/retrieval/v1/retrieval.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from arg_services.graph.v1 import graph_pb2 as arg__services_dot_graph_dot_v1_dot_graph__pb2
from arg_services.nlp.v1 import nlp_pb2 as arg__services_dot_nlp_dot_v1_dot_nlp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/retrieval/v1/retrieval.proto',
  package='arg_services.retrieval.v1',
  syntax='proto3',
  serialized_options=b'\n,de.uni_trier.recap.arg_services.retrieval.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)arg_services/retrieval/v1/retrieval.proto\x12\x19\x61rg_services.retrieval.v1\x1a!arg_services/graph/v1/graph.proto\x1a\x1d\x61rg_services/nlp/v1/nlp.proto\"\xe3\x03\n\x0fRetrieveRequest\x12\x44\n\x05\x63\x61ses\x18\x01 \x03(\x0b\x32\x35.arg_services.retrieval.v1.RetrieveRequest.CasesEntry\x12\x33\n\x0bquery_graph\x18\x02 \x01(\x0b\x32\x1c.arg_services.graph.v1.GraphH\x00\x12\x14\n\nquery_text\x18\x03 \x01(\tH\x00\x12\x32\n\nnlp_config\x18\x04 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x11\n\tmac_phase\x18\x06 \x01(\x08\x12\x11\n\tfac_phase\x18\x07 \x01(\x08\x12\x46\n\x11mapping_algorithm\x18\x08 \x01(\x0e\x32+.arg_services.retrieval.v1.MappingAlgorithm\x12\x1b\n\x13use_scheme_ontology\x18\t \x01(\x08\x12\x1c\n\x14\x65nforce_scheme_types\x18\n \x01(\x08\x1aJ\n\nCasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.arg_services.graph.v1.Graph:\x02\x38\x01\x42\x07\n\x05query\"\xce\x01\n\x10RetrieveResponse\x12\x39\n\x07ranking\x18\x01 \x03(\x0b\x32(.arg_services.retrieval.v1.RetrievedCase\x12=\n\x0bmac_ranking\x18\x02 \x03(\x0b\x32(.arg_services.retrieval.v1.RetrievedCase\x12@\n\x0b\x66\x61\x63_ranking\x18\x03 \x03(\x0b\x32+.arg_services.retrieval.v1.RetrievedMapping\"/\n\rRetrievedCase\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsimilarity\x18\x02 \x01(\x01\"\x85\x01\n\x10RetrievedMapping\x12\x36\n\x04\x63\x61se\x18\x01 \x01(\x0b\x32(.arg_services.retrieval.v1.RetrievedCase\x12\x39\n\rnode_mappings\x18\x02 \x03(\x0b\x32\".arg_services.retrieval.v1.Mapping\"@\n\x07Mapping\x12\x10\n\x08query_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61se_id\x18\x02 \x01(\t\x12\x12\n\nsimilarity\x18\x03 \x01(\x01*u\n\x10MappingAlgorithm\x12!\n\x1dMAPPING_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1b\n\x17MAPPING_ALGORITHM_ASTAR\x10\x01\x12!\n\x1dMAPPING_ALGORITHM_ISOMORPHISM\x10\x02\x32w\n\x10RetrievalService\x12\x63\n\x08Retrieve\x12*.arg_services.retrieval.v1.RetrieveRequest\x1a+.arg_services.retrieval.v1.RetrieveResponseB.\n,de.uni_trier.recap.arg_services.retrieval.v1b\x06proto3'
  ,
  dependencies=[arg__services_dot_graph_dot_v1_dot_graph__pb2.DESCRIPTOR,arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DESCRIPTOR,])

_MAPPINGALGORITHM = _descriptor.EnumDescriptor(
  name='MappingAlgorithm',
  full_name='arg_services.retrieval.v1.MappingAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAPPING_ALGORITHM_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAPPING_ALGORITHM_ASTAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAPPING_ALGORITHM_ISOMORPHISM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1084,
  serialized_end=1201,
)
_sym_db.RegisterEnumDescriptor(_MAPPINGALGORITHM)

MappingAlgorithm = enum_type_wrapper.EnumTypeWrapper(_MAPPINGALGORITHM)
MAPPING_ALGORITHM_UNSPECIFIED = 0
MAPPING_ALGORITHM_ASTAR = 1
MAPPING_ALGORITHM_ISOMORPHISM = 2



_RETRIEVEREQUEST_CASESENTRY = _descriptor.Descriptor(
  name='CasesEntry',
  full_name='arg_services.retrieval.v1.RetrieveRequest.CasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='arg_services.retrieval.v1.RetrieveRequest.CasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='arg_services.retrieval.v1.RetrieveRequest.CasesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=613,
)

_RETRIEVEREQUEST = _descriptor.Descriptor(
  name='RetrieveRequest',
  full_name='arg_services.retrieval.v1.RetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cases', full_name='arg_services.retrieval.v1.RetrieveRequest.cases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_graph', full_name='arg_services.retrieval.v1.RetrieveRequest.query_graph', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_text', full_name='arg_services.retrieval.v1.RetrieveRequest.query_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nlp_config', full_name='arg_services.retrieval.v1.RetrieveRequest.nlp_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='arg_services.retrieval.v1.RetrieveRequest.limit', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac_phase', full_name='arg_services.retrieval.v1.RetrieveRequest.mac_phase', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fac_phase', full_name='arg_services.retrieval.v1.RetrieveRequest.fac_phase', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping_algorithm', full_name='arg_services.retrieval.v1.RetrieveRequest.mapping_algorithm', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_scheme_ontology', full_name='arg_services.retrieval.v1.RetrieveRequest.use_scheme_ontology', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforce_scheme_types', full_name='arg_services.retrieval.v1.RetrieveRequest.enforce_scheme_types', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RETRIEVEREQUEST_CASESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query', full_name='arg_services.retrieval.v1.RetrieveRequest.query',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=139,
  serialized_end=622,
)


_RETRIEVERESPONSE = _descriptor.Descriptor(
  name='RetrieveResponse',
  full_name='arg_services.retrieval.v1.RetrieveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranking', full_name='arg_services.retrieval.v1.RetrieveResponse.ranking', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac_ranking', full_name='arg_services.retrieval.v1.RetrieveResponse.mac_ranking', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fac_ranking', full_name='arg_services.retrieval.v1.RetrieveResponse.fac_ranking', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=831,
)


_RETRIEVEDCASE = _descriptor.Descriptor(
  name='RetrievedCase',
  full_name='arg_services.retrieval.v1.RetrievedCase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='arg_services.retrieval.v1.RetrievedCase.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='similarity', full_name='arg_services.retrieval.v1.RetrievedCase.similarity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=880,
)


_RETRIEVEDMAPPING = _descriptor.Descriptor(
  name='RetrievedMapping',
  full_name='arg_services.retrieval.v1.RetrievedMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case', full_name='arg_services.retrieval.v1.RetrievedMapping.case', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_mappings', full_name='arg_services.retrieval.v1.RetrievedMapping.node_mappings', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1016,
)


_MAPPING = _descriptor.Descriptor(
  name='Mapping',
  full_name='arg_services.retrieval.v1.Mapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_id', full_name='arg_services.retrieval.v1.Mapping.query_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_id', full_name='arg_services.retrieval.v1.Mapping.case_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='similarity', full_name='arg_services.retrieval.v1.Mapping.similarity', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1082,
)

_RETRIEVEREQUEST_CASESENTRY.fields_by_name['value'].message_type = arg__services_dot_graph_dot_v1_dot_graph__pb2._GRAPH
_RETRIEVEREQUEST_CASESENTRY.containing_type = _RETRIEVEREQUEST
_RETRIEVEREQUEST.fields_by_name['cases'].message_type = _RETRIEVEREQUEST_CASESENTRY
_RETRIEVEREQUEST.fields_by_name['query_graph'].message_type = arg__services_dot_graph_dot_v1_dot_graph__pb2._GRAPH
_RETRIEVEREQUEST.fields_by_name['nlp_config'].message_type = arg__services_dot_nlp_dot_v1_dot_nlp__pb2._NLPCONFIG
_RETRIEVEREQUEST.fields_by_name['mapping_algorithm'].enum_type = _MAPPINGALGORITHM
_RETRIEVEREQUEST.oneofs_by_name['query'].fields.append(
  _RETRIEVEREQUEST.fields_by_name['query_graph'])
_RETRIEVEREQUEST.fields_by_name['query_graph'].containing_oneof = _RETRIEVEREQUEST.oneofs_by_name['query']
_RETRIEVEREQUEST.oneofs_by_name['query'].fields.append(
  _RETRIEVEREQUEST.fields_by_name['query_text'])
_RETRIEVEREQUEST.fields_by_name['query_text'].containing_oneof = _RETRIEVEREQUEST.oneofs_by_name['query']
_RETRIEVERESPONSE.fields_by_name['ranking'].message_type = _RETRIEVEDCASE
_RETRIEVERESPONSE.fields_by_name['mac_ranking'].message_type = _RETRIEVEDCASE
_RETRIEVERESPONSE.fields_by_name['fac_ranking'].message_type = _RETRIEVEDMAPPING
_RETRIEVEDMAPPING.fields_by_name['case'].message_type = _RETRIEVEDCASE
_RETRIEVEDMAPPING.fields_by_name['node_mappings'].message_type = _MAPPING
DESCRIPTOR.message_types_by_name['RetrieveRequest'] = _RETRIEVEREQUEST
DESCRIPTOR.message_types_by_name['RetrieveResponse'] = _RETRIEVERESPONSE
DESCRIPTOR.message_types_by_name['RetrievedCase'] = _RETRIEVEDCASE
DESCRIPTOR.message_types_by_name['RetrievedMapping'] = _RETRIEVEDMAPPING
DESCRIPTOR.message_types_by_name['Mapping'] = _MAPPING
DESCRIPTOR.enum_types_by_name['MappingAlgorithm'] = _MAPPINGALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RetrieveRequest = _reflection.GeneratedProtocolMessageType('RetrieveRequest', (_message.Message,), {

  'CasesEntry' : _reflection.GeneratedProtocolMessageType('CasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _RETRIEVEREQUEST_CASESENTRY,
    '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
    # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrieveRequest.CasesEntry)
    })
  ,
  'DESCRIPTOR' : _RETRIEVEREQUEST,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrieveRequest)
  })
_sym_db.RegisterMessage(RetrieveRequest)
_sym_db.RegisterMessage(RetrieveRequest.CasesEntry)

RetrieveResponse = _reflection.GeneratedProtocolMessageType('RetrieveResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVERESPONSE,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrieveResponse)
  })
_sym_db.RegisterMessage(RetrieveResponse)

RetrievedCase = _reflection.GeneratedProtocolMessageType('RetrievedCase', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDCASE,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrievedCase)
  })
_sym_db.RegisterMessage(RetrievedCase)

RetrievedMapping = _reflection.GeneratedProtocolMessageType('RetrievedMapping', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDMAPPING,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrievedMapping)
  })
_sym_db.RegisterMessage(RetrievedMapping)

Mapping = _reflection.GeneratedProtocolMessageType('Mapping', (_message.Message,), {
  'DESCRIPTOR' : _MAPPING,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.Mapping)
  })
_sym_db.RegisterMessage(Mapping)


DESCRIPTOR._options = None
_RETRIEVEREQUEST_CASESENTRY._options = None

_RETRIEVALSERVICE = _descriptor.ServiceDescriptor(
  name='RetrievalService',
  full_name='arg_services.retrieval.v1.RetrievalService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1203,
  serialized_end=1322,
  methods=[
  _descriptor.MethodDescriptor(
    name='Retrieve',
    full_name='arg_services.retrieval.v1.RetrievalService.Retrieve',
    index=0,
    containing_service=None,
    input_type=_RETRIEVEREQUEST,
    output_type=_RETRIEVERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RETRIEVALSERVICE)

DESCRIPTOR.services_by_name['RetrievalService'] = _RETRIEVALSERVICE

# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import arg_services.nlp.v1.nlp_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TopicsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DOCUMENTS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def documents(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    @property
    def config(self) -> arg_services.nlp.v1.nlp_pb2.NlpConfig: ...
    def __init__(self,
        *,
        documents : typing.Optional[typing.Iterable[typing.Text]] = ...,
        config : typing.Optional[arg_services.nlp.v1.nlp_pb2.NlpConfig] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config",u"documents",b"documents"]) -> None: ...
global___TopicsRequest = TopicsRequest

class TopicsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OUTLIERS_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    @property
    def outliers(self) -> global___Topic: ...
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Topic]: ...
    def __init__(self,
        *,
        outliers : typing.Optional[global___Topic] = ...,
        topics : typing.Optional[typing.Iterable[global___Topic]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"outliers",b"outliers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"outliers",b"outliers",u"topics",b"topics"]) -> None: ...
global___TopicsResponse = TopicsResponse

class Topic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COUNT_FIELD_NUMBER: builtins.int
    TERMS_FIELD_NUMBER: builtins.int
    count: builtins.int = ...
    @property
    def terms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Term]: ...
    def __init__(self,
        *,
        count : builtins.int = ...,
        terms : typing.Optional[typing.Iterable[global___Term]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"count",b"count",u"terms",b"terms"]) -> None: ...
global___Topic = Topic

class Term(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    score: builtins.float = ...
    def __init__(self,
        *,
        text : typing.Text = ...,
        score : builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"score",b"score",u"text",b"text"]) -> None: ...
global___Term = Term



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import arg_services.graph.v1.graph_pb2
import arg_services.nlp.v1.nlp_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MappingAlgorithm(_MappingAlgorithm, metaclass=_MappingAlgorithmEnumTypeWrapper):
    pass
class _MappingAlgorithm:
    V = typing.NewType('V', builtins.int)
class _MappingAlgorithmEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MappingAlgorithm.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    MAPPING_ALGORITHM_UNSPECIFIED = MappingAlgorithm.V(0)
    MAPPING_ALGORITHM_ASTAR = MappingAlgorithm.V(1)
    MAPPING_ALGORITHM_ISOMORPHISM = MappingAlgorithm.V(2)

MAPPING_ALGORITHM_UNSPECIFIED = MappingAlgorithm.V(0)
MAPPING_ALGORITHM_ASTAR = MappingAlgorithm.V(1)
MAPPING_ALGORITHM_ISOMORPHISM = MappingAlgorithm.V(2)
global___MappingAlgorithm = MappingAlgorithm


class RetrieveRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class CasesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        @property
        def value(self) -> arg_services.graph.v1.graph_pb2.Graph: ...
        def __init__(self,
            *,
            key : typing.Text = ...,
            value : typing.Optional[arg_services.graph.v1.graph_pb2.Graph] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    CASES_FIELD_NUMBER: builtins.int
    QUERY_GRAPH_FIELD_NUMBER: builtins.int
    QUERY_TEXT_FIELD_NUMBER: builtins.int
    NLP_CONFIG_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    MAC_PHASE_FIELD_NUMBER: builtins.int
    FAC_PHASE_FIELD_NUMBER: builtins.int
    MAPPING_ALGORITHM_FIELD_NUMBER: builtins.int
    USE_SCHEME_ONTOLOGY_FIELD_NUMBER: builtins.int
    ENFORCE_SCHEME_TYPES_FIELD_NUMBER: builtins.int
    @property
    def cases(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, arg_services.graph.v1.graph_pb2.Graph]: ...
    @property
    def query_graph(self) -> arg_services.graph.v1.graph_pb2.Graph: ...
    query_text: typing.Text = ...
    @property
    def nlp_config(self) -> arg_services.nlp.v1.nlp_pb2.NlpConfig: ...
    limit: builtins.int = ...
    mac_phase: builtins.bool = ...
    fac_phase: builtins.bool = ...
    mapping_algorithm: global___MappingAlgorithm.V = ...
    use_scheme_ontology: builtins.bool = ...
    enforce_scheme_types: builtins.bool = ...
    def __init__(self,
        *,
        cases : typing.Optional[typing.Mapping[typing.Text, arg_services.graph.v1.graph_pb2.Graph]] = ...,
        query_graph : typing.Optional[arg_services.graph.v1.graph_pb2.Graph] = ...,
        query_text : typing.Text = ...,
        nlp_config : typing.Optional[arg_services.nlp.v1.nlp_pb2.NlpConfig] = ...,
        limit : builtins.int = ...,
        mac_phase : builtins.bool = ...,
        fac_phase : builtins.bool = ...,
        mapping_algorithm : global___MappingAlgorithm.V = ...,
        use_scheme_ontology : builtins.bool = ...,
        enforce_scheme_types : builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"nlp_config",b"nlp_config",u"query",b"query",u"query_graph",b"query_graph",u"query_text",b"query_text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"cases",b"cases",u"enforce_scheme_types",b"enforce_scheme_types",u"fac_phase",b"fac_phase",u"limit",b"limit",u"mac_phase",b"mac_phase",u"mapping_algorithm",b"mapping_algorithm",u"nlp_config",b"nlp_config",u"query",b"query",u"query_graph",b"query_graph",u"query_text",b"query_text",u"use_scheme_ontology",b"use_scheme_ontology"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"query",b"query"]) -> typing.Optional[typing_extensions.Literal["query_graph","query_text"]]: ...
global___RetrieveRequest = RetrieveRequest

class RetrieveResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RANKING_FIELD_NUMBER: builtins.int
    MAC_RANKING_FIELD_NUMBER: builtins.int
    FAC_RANKING_FIELD_NUMBER: builtins.int
    @property
    def ranking(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RetrievedCase]: ...
    @property
    def mac_ranking(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RetrievedCase]: ...
    @property
    def fac_ranking(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RetrievedMapping]: ...
    def __init__(self,
        *,
        ranking : typing.Optional[typing.Iterable[global___RetrievedCase]] = ...,
        mac_ranking : typing.Optional[typing.Iterable[global___RetrievedCase]] = ...,
        fac_ranking : typing.Optional[typing.Iterable[global___RetrievedMapping]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"fac_ranking",b"fac_ranking",u"mac_ranking",b"mac_ranking",u"ranking",b"ranking"]) -> None: ...
global___RetrieveResponse = RetrieveResponse

class RetrievedCase(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    SIMILARITY_FIELD_NUMBER: builtins.int
    id: typing.Text = ...
    similarity: builtins.float = ...
    def __init__(self,
        *,
        id : typing.Text = ...,
        similarity : builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"id",b"id",u"similarity",b"similarity"]) -> None: ...
global___RetrievedCase = RetrievedCase

class RetrievedMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CASE_FIELD_NUMBER: builtins.int
    NODE_MAPPINGS_FIELD_NUMBER: builtins.int
    @property
    def case(self) -> global___RetrievedCase: ...
    @property
    def node_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Mapping]: ...
    def __init__(self,
        *,
        case : typing.Optional[global___RetrievedCase] = ...,
        node_mappings : typing.Optional[typing.Iterable[global___Mapping]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"case",b"case"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"case",b"case",u"node_mappings",b"node_mappings"]) -> None: ...
global___RetrievedMapping = RetrievedMapping

class Mapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERY_ID_FIELD_NUMBER: builtins.int
    CASE_ID_FIELD_NUMBER: builtins.int
    SIMILARITY_FIELD_NUMBER: builtins.int
    query_id: typing.Text = ...
    case_id: typing.Text = ...
    similarity: builtins.float = ...
    def __init__(self,
        *,
        query_id : typing.Text = ...,
        case_id : typing.Text = ...,
        similarity : builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"case_id",b"case_id",u"query_id",b"query_id",u"similarity",b"similarity"]) -> None: ...
global___Mapping = Mapping



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Granularity(_Granularity, metaclass=_GranularityEnumTypeWrapper):
    pass
class _Granularity:
    V = typing.NewType('V', builtins.int)
class _GranularityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Granularity.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    GRANULARITY_UNSPECIFIED = Granularity.V(0)
    GRANULARITY_SENTENCE = Granularity.V(1)
    GRANULARITY_SUBSENTENCE = Granularity.V(2)
    GRANULARITY_PARAGRAPH = Granularity.V(3)

GRANULARITY_UNSPECIFIED = Granularity.V(0)
GRANULARITY_SENTENCE = Granularity.V(1)
GRANULARITY_SUBSENTENCE = Granularity.V(2)
GRANULARITY_PARAGRAPH = Granularity.V(3)
global___Granularity = Granularity


class Classifier(_Classifier, metaclass=_ClassifierEnumTypeWrapper):
    pass
class _Classifier:
    V = typing.NewType('V', builtins.int)
class _ClassifierEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Classifier.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    CLASSIFIER_UNSPECIFIED = Classifier.V(0)
    CLASSIFIER_TWO_WAY = Classifier.V(1)
    CLASSIFIER_THREE_WAY = Classifier.V(2)
    CLASSIFIER_SEQUENTIAL = Classifier.V(3)

CLASSIFIER_UNSPECIFIED = Classifier.V(0)
CLASSIFIER_TWO_WAY = Classifier.V(1)
CLASSIFIER_THREE_WAY = Classifier.V(2)
CLASSIFIER_SEQUENTIAL = Classifier.V(3)
global___Classifier = Classifier


class SegmentationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    GRANULARITY_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    granularity: global___Granularity.V = ...
    def __init__(self,
        *,
        text : typing.Text = ...,
        granularity : global___Granularity.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"granularity",b"granularity",u"text",b"text"]) -> None: ...
global___SegmentationRequest = SegmentationRequest

class SegmentationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        segments : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"segments",b"segments"]) -> None: ...
global___SegmentationResponse = SegmentationResponse

class ClassificationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEGMENTS_FIELD_NUMBER: builtins.int
    CLASSIFIER_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    classifier: global___Classifier.V = ...
    def __init__(self,
        *,
        segments : typing.Optional[typing.Iterable[typing.Text]] = ...,
        classifier : global___Classifier.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"classifier",b"classifier",u"segments",b"segments"]) -> None: ...
global___ClassificationRequest = ClassificationRequest

class ClassificationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClassifiedSegment]: ...
    def __init__(self,
        *,
        segments : typing.Optional[typing.Iterable[global___ClassifiedSegment]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"segments",b"segments"]) -> None: ...
global___ClassificationResponse = ClassificationResponse

class ClassifiedSegment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    ADU_FIELD_NUMBER: builtins.int
    CLAIM_FIELD_NUMBER: builtins.int
    PREMISE_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    adu: builtins.bool = ...
    claim: builtins.bool = ...
    premise: builtins.bool = ...
    def __init__(self,
        *,
        text : typing.Text = ...,
        adu : builtins.bool = ...,
        claim : builtins.bool = ...,
        premise : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"adu",b"adu",u"claim",b"claim",u"premise",b"premise",u"text",b"text"]) -> None: ...
global___ClassifiedSegment = ClassifiedSegment



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.retrieval.v1.retrieval_pb2
import grpc

class RetrievalServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Retrieve: grpc.UnaryUnaryMultiCallable[
        arg_services.retrieval.v1.retrieval_pb2.RetrieveRequest,
        arg_services.retrieval.v1.retrieval_pb2.RetrieveResponse] = ...


class RetrievalServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Retrieve(self,
        request: arg_services.retrieval.v1.retrieval_pb2.RetrieveRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.retrieval.v1.retrieval_pb2.RetrieveResponse: ...


def add_RetrievalServiceServicer_to_server(servicer: RetrievalServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Prediction(_Prediction, metaclass=_PredictionEnumTypeWrapper):
    pass
class _Prediction:
    V = typing.NewType('V', builtins.int)
class _PredictionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Prediction.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    PREDICTION_UNSPECIFIED = Prediction.V(0)
    PREDICTION_ENTAILMENT = Prediction.V(1)
    PREDICTION_CONTRADICTION = Prediction.V(2)
    PREDICTION_NEUTRAL = Prediction.V(3)

PREDICTION_UNSPECIFIED = Prediction.V(0)
PREDICTION_ENTAILMENT = Prediction.V(1)
PREDICTION_CONTRADICTION = Prediction.V(2)
PREDICTION_NEUTRAL = Prediction.V(3)
global___Prediction = Prediction


class EntailmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LANGUAGE_FIELD_NUMBER: builtins.int
    PREMISE_FIELD_NUMBER: builtins.int
    CLAIM_FIELD_NUMBER: builtins.int
    language: typing.Text = ...
    premise: typing.Text = ...
    claim: typing.Text = ...
    def __init__(self,
        *,
        language : typing.Text = ...,
        premise : typing.Text = ...,
        claim : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"claim",b"claim",u"language",b"language",u"premise",b"premise"]) -> None: ...
global___EntailmentRequest = EntailmentRequest

class EntailmentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERIES_FIELD_NUMBER: builtins.int
    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntailmentRequest]: ...
    def __init__(self,
        *,
        queries : typing.Optional[typing.Iterable[global___EntailmentRequest]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"queries",b"queries"]) -> None: ...
global___EntailmentsRequest = EntailmentsRequest

class EntailmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PREDICTION_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    prediction: global___Prediction.V = ...
    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Detail]: ...
    def __init__(self,
        *,
        prediction : global___Prediction.V = ...,
        details : typing.Optional[typing.Iterable[global___Detail]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"details",b"details",u"prediction",b"prediction"]) -> None: ...
global___EntailmentResponse = EntailmentResponse

class EntailmentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntailmentResponse]: ...
    def __init__(self,
        *,
        results : typing.Optional[typing.Iterable[global___EntailmentResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"results",b"results"]) -> None: ...
global___EntailmentsResponse = EntailmentsResponse

class Detail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROBABILITY_FIELD_NUMBER: builtins.int
    PREDICTION_FIELD_NUMBER: builtins.int
    probability: builtins.float = ...
    prediction: global___Prediction.V = ...
    def __init__(self,
        *,
        probability : builtins.float = ...,
        prediction : global___Prediction.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"prediction",b"prediction",u"probability",b"probability"]) -> None: ...
global___Detail = Detail



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['arg_services',
 'arg_services.adu',
 'arg_services.adu.v1',
 'arg_services.base',
 'arg_services.base.v1',
 'arg_services.entailment',
 'arg_services.entailment.v1',
 'arg_services.graph',
 'arg_services.graph.v1',
 'arg_services.nlp',
 'arg_services.nlp.v1',
 'arg_services.retrieval',
 'arg_services.retrieval.v1',
 'arg_services.topic_modeling',
 'arg_services.topic_modeling.v1',
 'arg_services_helper']

package_data = \
{'': ['*']}

install_requires = \
['grpcio-reflection>=1.39.0,<2.0.0',
 'grpcio>=1.32,<2.0',
 'protobuf>=3.15.8,<4.0.0']

setup_kwargs = {
    'name': 'arg-services',
    'version': '0.1.27',
    'description': 'gRPC definitions for microservice-based argumentation machines',
    'long_description': '# Argumentation Microservices\n',
    'author': 'Mirko Lenz',
    'author_email': 'info@mirko-lenz.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'http://recap.uni-trier.de',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
